@@ -78,6 +78,7 @@ class MultiBackend(BaseBackend):
     default_port = None
     type = None
     interval = 1
+    polling = True
     _prefetch_count = None
 
     def __init__(self, connection, **kwargs):
@@ -92,11 +93,13 @@ class MultiBackend(BaseBackend):
 
     def establish_connection(self):
         conninfo = self.connection
-        return Connection(self.type, host=conninfo.hostname,
+        conn = Connection(self.type, host=conninfo.hostname,
                                      user=conninfo.userid,
                                      password=conninfo.password,
                                      database=conninfo.virtual_host,
                                      port=conninfo.port)
+        conn.drain_events = self.drain_events
+        return conn
 
     def close_connection(self, connection):
         connection.close()
@@ -105,7 +108,7 @@ class MultiBackend(BaseBackend):
         return True
 
     def queue_purge(self, queue, **kwargs):
-        self.channel.Queue(queue).purge()
+        return self.channel.Queue(queue).purge()
 
     def _poll(self, resource):
         while True:
@@ -114,27 +117,28 @@ class MultiBackend(BaseBackend):
                     return resource.get()
                 except QueueEmpty:
                     pass
-            time.sleep(self.interval)
+            self.polling and time.sleep(self.interval)
 
     def declare_consumer(self, queue, no_ack, callback, consumer_tag,
                          **kwargs):
         self._consumers[consumer_tag] = queue
         self._callbacks[queue] = callback
 
-    def consume(self, limit=None):
+    def drain_events(self, timeout=None):
         queueset = self.channel.QueueSet(self._consumers.values())
+        payload, queue = self._poll(queueset)
 
+        if not queue or queue not in self._callbacks:
+            return
+
+        self._callbacks[queue](payload)
+
+    def consume(self, limit=None):
         for total_message_count in count():
-
             if limit and total_message_count >= limit:
                 raise StopIteration
 
-            payload, queue = self._poll(queueset)
-
-            if not queue or queue not in self._callbacks:
-                continue
-
-            self._callbacks[queue](payload)
+            self.drain_events()
 
             yield True
 
@@ -211,7 +215,12 @@ class MultiBackend(BaseBackend):
 
 class Redis(MultiBackend):
     type = "Redis"
+    polling = False
 
 
 class Database(MultiBackend):
     type = "database"
+
+
+class MongoDB(MultiBackend):
+    type = "mongodb"
